# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "BONES",
    "MUSCLES",
]

DICT_SUB_STRUCTURES = {
    "BONES":[
        'Clavicle',
        'Elbow',
        'Glenoid',
        'Humerus',
        'Scapula',
        'Sternum',
        'Vertebrae'],

    "MUSCLES":[     
        'Biceps',
        'Coracobrachialis',
        'Deltoid',
        'Latissimus dorsi',
        'Pectoralis',
        'Rhomboid',
        'Teres major',
        'Trapezius',
        'Triceps brachii',
        'Cuff Muscles',
        'Tendons']
}

DICT_SUB_SUB_STRUCTURES = {
    "Scapula":[
        'Acromion',
        'Body',
        'Coracoid process',
        'Spine'],

    "Humerus":[
        'Diaphyse',
        'Head',
        'Trochiter',
        'Trochin'],

    "Cuff Muscles":[
        'Infra-spinatus',
        'Sub-scapularis',
        'Supra-spinatus',
        'Terres minor'],

    "Elbow":[
        'Humeral pallet',
        'Olecranon',
        'Radius'],

    "Deltoid":[
        'Anterior',
        'Lateral',
        'Posterior'],

    "Biceps":[
        'Long',
        'Short'],

    "Pectoralis":[
        'Major',
        'Minor'],    
}