# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "BONES",
]

DICT_SUB_STRUCTURES = {
    "BONES":[
        'Initial Results',
        'Clavicle',
        'Humerus',
        'Ribs',
        'Scapula',
        'Sternum',
        'Vertebrae', 
        'Radius',
        'Ulna']
}